@@ -93,7 +93,9 @@ async def test_get_image_layer_to_disk(
     manifest = await archive_image_source.get_manifest(image_name, **kwargs)
     for layer in manifest.get_layers(image_name):
         LOGGER.debug("Retrieving blob: %s/%s ...", image_name, layer)
-        async with aiotempfile(mode="w+b") as file:
+        async with aiotempfile(
+            mode="w+b", prefix=f"tmp{test_get_image_layer_to_disk.__name__}"
+        ) as file:
             result = await archive_image_source.get_image_layer_to_disk(
                 image_name, layer, file, **kwargs
             )
@@ -168,27 +170,32 @@ async def test_put_image(
     await archive_image_source_dest.put_image(
         archive_image_source_src,
         image_name,
-        response["manifest"],
-        response["image_config"],
-        response["uncompressed_layer_files"],
+        response.manifest,
+        response.image_config,
+        response.uncompressed_layer_files,
         **kwargs,
     )
 
     LOGGER.debug("Retrieving image configuration for: %s ...", image_name)
     tmp = await archive_image_source_dest.get_image_config(image_name, **kwargs)
-    assert tmp.get_digest() == response["image_config"].get_digest()
+    assert tmp.get_digest() == response.image_config.get_digest()
 
     LOGGER.debug("Retrieving manifest for: %s ...", image_name)
     manifest = await archive_image_source_dest.get_manifest(image_name, **kwargs)
     for layer in manifest.get_layers(image_name):
         LOGGER.debug("Retrieving blob: %s/%s ...", image_name, layer)
-        async with aiotempfile(mode="w+b") as file:
+        async with aiotempfile(
+            mode="w+b", prefix=f"tmp{test_put_image.__name__}"
+        ) as file:
             result = await archive_image_source_dest.get_image_layer_to_disk(
                 image_name, layer, file, **kwargs
             )
             LOGGER.debug("Verifying digest of written file ...")
         # TODO: What is the correct digest value?
 
+    for file in response.compressed_layer_files + response.uncompressed_layer_files:
+        file.close()
+
 
 async def test_put_image_config(
     known_good_image_archive: TypingKnownGoodImageArchive, **kwargs
@@ -301,37 +308,42 @@ async def test_sign_image_same_image_source(
     def assertions(result: ImageSourceSignImage):
         assert result
 
-        image_config = result["image_config"]
+        image_config = result.image_config
         assert image_config
         assert "FAKE SIGNATURE" in str(image_config)
 
-        signature_value = result["signature_value"]
+        signature_value = result.signature_value
         assert signature_value
         assert "FAKE SIGNATURE" in signature_value
 
-        verify_image_data = result["verify_image_data"]
+        verify_image_data = result.verify_image_data
         assert verify_image_data
-        assert image_config == verify_image_data["image_config"]
+        assert image_config == verify_image_data.image_config
 
-        manifest = verify_image_data["manifest"]
+        manifest = verify_image_data.manifest
         assert manifest
 
-        manifest_signed = result["manifest_signed"]
+        manifest_signed = result.manifest_signed
         assert manifest_signed
         assert manifest_signed.get_config_digest() == image_config.get_digest()
         assert len(manifest_signed.get_layers()) == len(image_config.get_image_layers())
 
     # 1. Single signature
-    assertions(
-        await archive_image_source.sign_image(
-            FakeSigner(),
-            image_name,
-            archive_image_source,
-            dest_image_name,
-            SignatureTypes.SIGN,
-            **kwargs,
-        )
+    response = await archive_image_source.sign_image(
+        FakeSigner(),
+        image_name,
+        archive_image_source,
+        dest_image_name,
+        SignatureTypes.SIGN,
+        **kwargs,
     )
+    assertions(response)
+
+    for file in (
+        response.verify_image_data.compressed_layer_files
+        + response.verify_image_data.uncompressed_layer_files
+    ):
+        file.close()
 
     # TODO: Test signing image twice (with same key, with different keys ...)
 
@@ -353,37 +365,42 @@ async def test_sign_image_different_image_source(
     def assertions(result: ImageSourceSignImage):
         assert result
 
-        image_config = result["image_config"]
+        image_config = result.image_config
         assert image_config
         assert "FAKE SIGNATURE" in str(image_config)
 
-        signature_value = result["signature_value"]
+        signature_value = result.signature_value
         assert signature_value
         assert "FAKE SIGNATURE" in signature_value
 
-        verify_image_data = result["verify_image_data"]
+        verify_image_data = result.verify_image_data
         assert verify_image_data
-        assert image_config == verify_image_data["image_config"]
+        assert image_config == verify_image_data.image_config
 
-        manifest = verify_image_data["manifest"]
+        manifest = verify_image_data.manifest
         assert manifest
 
-        manifest_signed = result["manifest_signed"]
+        manifest_signed = result.manifest_signed
         assert manifest_signed
         assert manifest_signed.get_config_digest() == image_config.get_digest()
         assert len(manifest_signed.get_layers()) == len(image_config.get_image_layers())
 
     # 1. Single signature
-    assertions(
-        await archive_image_source_src.sign_image(
-            FakeSigner(),
-            image_name,
-            archive_image_source_dest,
-            dest_image_name,
-            SignatureTypes.SIGN,
-            **kwargs,
-        )
+    response = await archive_image_source_src.sign_image(
+        FakeSigner(),
+        image_name,
+        archive_image_source_dest,
+        dest_image_name,
+        SignatureTypes.SIGN,
+        **kwargs,
     )
+    assertions(response)
+
+    for file in (
+        response.verify_image_data.compressed_layer_files
+        + response.verify_image_data.uncompressed_layer_files
+    ):
+        file.close()
 
     # TODO: Test signing image twice (with same key, with different keys ...)
 
@@ -398,10 +415,10 @@ async def test_verify_image_integrity(
     def assertions(result: ImageSourceVerifyImageIntegrity):
         assert result
 
-        image_config = result["image_config"]
+        image_config = result.image_config
         assert image_config
 
-        manifest = result["manifest"]
+        manifest = result.manifest
         assert manifest
 
         # TODO: Uncomment if / when archive image source supports this ...
@@ -410,6 +427,10 @@ async def test_verify_image_integrity(
         # )
 
     # 1. Unsigned
-    assertions(await archive_image_source.verify_image_integrity(image_name, **kwargs))
+    response = await archive_image_source.verify_image_integrity(image_name, **kwargs)
+    assertions(response)
+
+    for file in response.compressed_layer_files + response.uncompressed_layer_files:
+        file.close()
 
     # TODO: Test integrity on a signed image ...
